@@ -37,11 +37,11 @@
 #include "tools/kpTool.h"
 #include "kpToolPrivate.h"
 
-#include <limits.h>
+#include <climits>
 
-#include <qapplication.h>
-#include <qcursor.h>
-#include <qevent.h>
+#include <QApplication>
+#include <QCursor>
+#include <QEvent>
 
 #include <kactioncollection.h>
 #include "kpLogCategories.h"
@@ -97,22 +97,24 @@ void kpTool::arrowKeyPressDirection (const QKeyEvent *e, int *dx, int *dy)
 
     switch (e->key ())
     {
-    case Qt::Key_Home:     dxLocal = -1, dyLocal = -1;    break;
-    case Qt::Key_Up:                     dyLocal = -1;    break;
-    case Qt::Key_PageUp:   dxLocal = +1, dyLocal = -1;    break;
+    case Qt::Key_Home:      dxLocal = -1;   dyLocal = -1;   break;
+    case Qt::Key_Up:                        dyLocal = -1;   break;
+    case Qt::Key_PageUp:    dxLocal = +1;   dyLocal = -1;   break;
 
-    case Qt::Key_Left:     dxLocal = -1;                  break;
-    case Qt::Key_Right:    dxLocal = +1;                  break;
+    case Qt::Key_Left:      dxLocal = -1;                   break;
+    case Qt::Key_Right:     dxLocal = +1;                   break;
 
-    case Qt::Key_End:      dxLocal = -1, dyLocal = +1;    break;
-    case Qt::Key_Down:                   dyLocal = +1;    break;
-    case Qt::Key_PageDown: dxLocal = +1, dyLocal = +1;    break;
+    case Qt::Key_End:       dxLocal = -1;   dyLocal = +1;   break;
+    case Qt::Key_Down:                      dyLocal = +1;   break;
+    case Qt::Key_PageDown:  dxLocal = +1;   dyLocal = +1;   break;
     }
 
-    if (dx)
+    if (dx) {
         *dx = dxLocal;
-    if (dy)
+    }
+    if (dy) {
         *dy = dyLocal;
+    }
 }
 
 //---------------------------------------------------------------------
@@ -122,13 +124,15 @@ void kpTool::seeIfAndHandleArrowKeyPress (QKeyEvent *e)
     int dx, dy;
 
     arrowKeyPressDirection (e, &dx, &dy);
-    if (dx == 0 && dy == 0)
+    if (dx == 0 && dy == 0) {
         return;
+    }
 
 
     kpView * const view = viewUnderCursor ();
-    if (!view)
+    if (!view) {
         return;
+    }
 
 
     const QPoint oldPoint = view->mapFromGlobal (QCursor::pos ());
@@ -155,7 +159,8 @@ void kpTool::seeIfAndHandleArrowKeyPress (QKeyEvent *e)
     if (view->transformViewToDoc (QPoint (newViewX, newViewY)) ==
         view->transformViewToDoc (oldPoint))
     {
-        newViewX += viewIncX, newViewY += viewIncY;
+        newViewX += viewIncX;
+        newViewY += viewIncY;
 
     #if DEBUG_KP_TOOL && 0
         qCDebug(kpLogTools) << "\tneed adjust for doc - newPoint="
@@ -188,11 +193,13 @@ bool kpTool::isDrawKey (int key)
 
 void kpTool::seeIfAndHandleBeginDrawKeyPress (QKeyEvent *e)
 {
-    if (e->isAutoRepeat ())
+    if (e->isAutoRepeat ()) {
         return;
+    }
 
-    if (!isDrawKey (e->key ()))
+    if (!isDrawKey (e->key ())) {
         return;
+    }
 
 #if DEBUG_KP_TOOL && 0
     qCDebug(kpLogTools) << "kpTool::seeIfAndHandleBeginDrawKeyPress() accept";
@@ -201,8 +208,9 @@ void kpTool::seeIfAndHandleBeginDrawKeyPress (QKeyEvent *e)
 
     // TODO: wrong for dragging lines outside of view (for e.g.)
     kpView * const view = viewUnderCursor ();
-    if (!view)
+    if (!view) {
         return;
+    }
 
 
     // TODO: what about the modifiers?
@@ -225,11 +233,13 @@ void kpTool::seeIfAndHandleEndDrawKeyPress (QKeyEvent *e)
                << endl;
 #endif
 
-    if (e->isAutoRepeat ())
+    if (e->isAutoRepeat ()) {
         return;
+    }
 
-    if (!isDrawKey (e->key ()))
+    if (!isDrawKey (e->key ())) {
         return;
+    }
 
 #if DEBUG_KP_TOOL && 0
     qCDebug(kpLogTools) << "kpTool::seeIfAndHandleEndDrawKeyPress() accept";
@@ -237,8 +247,9 @@ void kpTool::seeIfAndHandleEndDrawKeyPress (QKeyEvent *e)
 
 
     kpView * const view = viewUnderCursor ();
-    if (!view)
+    if (!view) {
         return;
+    }
 
 
     // TODO: what about the modifiers?
@@ -259,24 +270,26 @@ void kpTool::keyPressEvent (QKeyEvent *e)
 #if DEBUG_KP_TOOL && 0
     qCDebug(kpLogTools) << "kpTool::keyPressEvent() key=" << (int *) e->key ()
               << " stateAfter: modifiers=" << (int *) (int) e->modifiers ()
-              << " isAutoRep=" << e->isAutoRepeat ()
-              << endl;
+              << " isAutoRep=" << e->isAutoRepeat ();
 #endif
 
     e->ignore ();
 
 
     seeIfAndHandleModifierKey (e);
-    if (e->isAccepted ())
+    if (e->isAccepted ()) {
         return;
+    }
 
     seeIfAndHandleArrowKeyPress (e);
-    if (e->isAccepted ())
+    if (e->isAccepted ()) {
         return;
+    }
 
     seeIfAndHandleBeginDrawKeyPress (e);
-    if (e->isAccepted ())
+    if (e->isAccepted ()) {
         return;
+    }
 
 
     switch (e->key ())
@@ -303,19 +316,20 @@ void kpTool::keyReleaseEvent (QKeyEvent *e)
 #if DEBUG_KP_TOOL && 0
     qCDebug(kpLogTools) << "kpTool::keyReleaseEvent() key=" << (int *) e->key ()
               << " stateAfter: modifiers=" << (int *) (int) e->modifiers ()
-              << " isAutoRep=" << e->isAutoRepeat ()
-              << endl;
+              << " isAutoRep=" << e->isAutoRepeat ();
 #endif
 
     e->ignore ();
 
     seeIfAndHandleModifierKey (e);
-    if (e->isAccepted ())
+    if (e->isAccepted ()) {
         return;
+    }
 
     seeIfAndHandleEndDrawKeyPress (e);
-    if (e->isAccepted ())
+    if (e->isAccepted ()) {
         return;
+    }
 }
 
 //---------------------------------------------------------------------
@@ -362,8 +376,9 @@ void kpTool::notifyModifierStateChanged ()
 {
     if (careAboutModifierState ())
     {
-        if (d->beganDraw)
+        if (d->beganDraw) {
             draw (d->currentPoint, d->lastPoint, normalizedRect ());
+        }
         else
         {
             d->currentPoint = calculateCurrentPoint ();
@@ -377,8 +392,9 @@ void kpTool::notifyModifierStateChanged ()
 
 void kpTool::setShiftPressed (bool pressed)
 {
-    if (pressed == d->shiftPressed)
+    if (pressed == d->shiftPressed) {
         return;
+    }
 
     d->shiftPressed = pressed;
 
@@ -389,8 +405,9 @@ void kpTool::setShiftPressed (bool pressed)
 
 void kpTool::setControlPressed (bool pressed)
 {
-    if (pressed == d->controlPressed)
+    if (pressed == d->controlPressed) {
         return;
+    }
 
     d->controlPressed = pressed;
 
@@ -401,8 +418,9 @@ void kpTool::setControlPressed (bool pressed)
 
 void kpTool::setAltPressed (bool pressed)
 {
-    if (pressed == d->altPressed)
+    if (pressed == d->altPressed) {
         return;
+    }
 
     d->altPressed = pressed;
 
